@@ -30,7 +30,7 @@
 #define _ATALK_ADOUBLE_H
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <fcntl.h>
@@ -216,7 +216,7 @@ struct adouble {
     int                 ad_data_refcount;
     int                 ad_meta_refcount;
     int                 ad_reso_refcount;
-    off_t               ad_rlen;           /* ressource fork len with AFP 3.0         *
+    off_t               ad_rlen;           /* resource fork len with AFP 3.0         *
                                             * the header parameter size is too small. */
     char                *ad_name;          /* mac name (maccharset or UTF8-MAC)       */
     struct adouble_fops *ad_ops;
@@ -230,7 +230,7 @@ struct adouble {
 #define ADFLAGS_HF        (1<<2)
 #define ADFLAGS_DIR       (1<<3)
 #define ADFLAGS_NOHF      (1<<4)  /* not an error if no metadata fork */
-#define ADFLAGS_NORF      (1<<5)  /* not an error if no ressource fork */
+#define ADFLAGS_NORF      (1<<5)  /* not an error if no resource fork */
 #define ADFLAGS_CHECK_OF  (1<<6)  /* check for open forks from us and other afpd's */
 #define ADFLAGS_SETSHRMD  (1<<7)  /* setting share mode must be done with excl fcnt lock,
                                      which implies that the file must be openend rw.
@@ -412,6 +412,9 @@ extern void ad_init       (struct adouble *, const struct vol * restrict);
 extern void ad_init_old   (struct adouble *ad, int flags, int options);
 extern int ad_init_offsets(struct adouble *ad);
 extern int ad_open        (struct adouble *ad, const char *path, int adflags, ...);
+#ifdef __APPLE__
+extern int ad_open_native_finderinfo(const char *path, char *ret);
+#endif
 extern int ad_openat      (struct adouble *, int dirfd, const char *path, int adflags, ...);
 extern int ad_refresh     (const char *path, struct adouble *);
 extern int ad_stat        (const char *, struct stat *);
@@ -433,7 +436,7 @@ extern ssize_t adf_pread(struct ad_fd *, void *, size_t, off_t);
 extern ssize_t adf_pwrite(struct ad_fd *, const void *, size_t, off_t);
 extern int     ad_dtruncate(struct adouble *, off_t);
 extern int     ad_rtruncate(struct adouble *, const char *, off_t);
-extern int     copy_fork(int eid, struct adouble *add, struct adouble *ads, char *buf, size_t buflen);
+extern int     copy_fork(int eid, struct adouble *add, struct adouble *ads, uint8_t *buf, size_t buflen);
 
 /* ad_size.c */
 extern off_t ad_size (const struct adouble *, uint32_t );
